==> lxqt-session_0.17.1.orig.tar.xz: lxqt-session-0.17.1/lxqt-config-session/translations/lxqt-config-session_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Sistem çekmecesi için bekleyin</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Uygulama Seç</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Evrensel Kendiliğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>LXQt Kendiliğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Konum: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Geçersiz kılınan: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Uygulama Kendiliğinden Çalıştırıcı</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>&apos;%1&apos; dosyası zaten var!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Pencere Yönetici</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQT Modülleri</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Oturumu kapatırken sor</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Uykuya/Askıya alamadan önce ekranı kilitle</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="131"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Kilit sonrası Bekleme/Askıya almak için bekleme süresi:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="144"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Basit Ayarlar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Dur</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>Select a window manager</source>
        <translation>Bir pencere yöneticisi seçin</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Ortam Değişkenleri (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Değişken Adı</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Çalışıyor</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>LXQT Oturum Ayarları</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Temel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Kullanıcı Dizinleri</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Kendilğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Ortam (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="87"/>
        <source>Session Restart Required</source>
        <translation>Oturumun yeniden başlatılması gerekli</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="88"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Bazı ayarlar yeniden başlayıncaya kadar etkin olmayacak.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Kişisel Dosyaların Yerleri</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQT Oturum Ayarları - Kullanıcı Dizinleri</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="186"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>%1 konumu için ayarlar uygulanırken hata oluştu</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="202"/>
        <source>Choose Location</source>
        <translation>Konum Seç</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Şablonlar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Paylaşılanlar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Müzikler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Masaüstünde gördüğünüz tüm dosyaları içerir</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>İndirilen dosyalarınızın kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Şablonlarınızın kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Paylaşılan dosyalarınızın kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Belgelerinizin kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Müziklerinizin yükleneceği ya da kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Resimlerinizin kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Videolarınızın kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
</context>
</TS>

==> lxqt-session_1.2.0.orig.tar.xz: lxqt-session-1.2.0/lxqt-config-session/translations/lxqt-config-session_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Sistem çekmecesi için bekleyin</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Uygulama Seç</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Evrensel Kendiliğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>LXQt Kendiliğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Konum: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Geçersiz kılınan: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Uygulama Kendiliğinden Çalıştırıcı</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>&apos;%1&apos; dosyası zaten var!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Pencere Yönetici</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Ara...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQT Modülleri</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation>Küresel Ekran Ölçekleme</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation>Ölçek faktörü:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Oturumu kapatırken sor</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Uykuya/Askıya alamadan önce ekranı kilitle</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Kilit sonrası Bekleme/Askıya almak için bekleme süresi:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Basit Ayarlar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Dur</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Bir pencere yöneticisi seçin</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Ortam Değişkenleri (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Değişken Adı</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Çalışıyor</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>LXQT Oturum Ayarları</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Temel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Kullanıcı Dizinleri</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Kendilğinden Başlatma</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Ortam (Gelişmiş)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>Oturumun yeniden başlatılması gerekli</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Bazı ayarlar yeniden başlayıncaya kadar etkin olmayacak.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Kişisel Dosyaların Yerleri</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQT Oturum Ayarları - Kullanıcı Dizinleri</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>%1 konumu için ayarlar uygulanırken hata oluştu</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Konum Seç</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Şablonlar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Paylaşılanlar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Müzikler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Masaüstünde gördüğünüz tüm dosyaları içerir</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>İndirilen dosyalarınızın kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Şablonlarınızın kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Paylaşılan dosyalarınızın kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Belgelerinizin kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Müziklerinizin yükleneceği ya da kaydedileceği öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Resimlerinizin kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Videolarınızın kaydedileceği veya alınacağı öntanımlı dizin</translation>
    </message>
</context>
</TS>
